@@ -157,50 +157,26 @@ void mpgfile::decodegop(int start, int stop, std::list<avframe*> &framelist)
     if (!firstsequence || idx[streampic].getsequencenumber()>=seqnr)
     {
       const uint8_t *data=(const uint8_t*)sd->getdata();
-      int frameFinished=0;
 
-      int decodebytes=bytes;
-      while (decodebytes>0)
+      AVPacket* pkt = av_packet_alloc();
+      pkt->data = (uint8_t*) data;
+      pkt->size = bytes;
+      avcodec_send_packet(S->avcc, pkt);
+      while (avcodec_receive_frame(S->avcc, avf) == 0)
       {
-        frameFinished=0;
-
-        AVPacket pkt;
-        av_init_packet( &pkt );
-        pkt.data = (uint8_t*) data;
-        pkt.size = decodebytes;
-        int bytesDecoded=avcodec_decode_video2( S->avcc, avf,
-                                        &frameFinished, &pkt );
-
-        if (bytesDecoded<0)
-        {
-          fprintf(stderr,"libavcodec error while decoding frame #%d\n",pic);
-          avcodec_close(S->avcc);
-          return;
-        }
-
-        data+=bytesDecoded;
-        decodebytes-=bytesDecoded;
-
-        if (frameFinished)
-        {
-          //fprintf(stderr, "* decoded frame %5d ilace:%d typ:%d pts=%f\n", pic, avf->interlaced_frame, avf->pict_type, (double)avf->pts/90000.0);
-          if (last_cpn!=avf->coded_picture_number)
-          {
-            last_cpn=avf->coded_picture_number;
-            if (pic>=start)
-              framelist.push_back(new avframe(avf,S->avcc));
-            ++pic;
-            if (pic>=stop)
-            {
-              frameFinished=0;
-              decodebytes=0;
-              break;
-            }
+        //fprintf(stderr, "* decoded frame %5d ilace:%d typ:%d pts=%f\n", pic, avf->interlaced_frame, avf->pict_type, (double)avf->pts/90000.0);
+        if (last_cpn!=avf->coded_picture_number) {
+          last_cpn=avf->coded_picture_number;
+          if (pic>=start) {
+            framelist.push_back(new avframe(avf,S->avcc));
+          }
+          ++pic;
+          if (pic>=stop) {
+            break;
           }
-          else
-            frameFinished=0;
         }
       }
+      av_packet_free(&pkt);
     }
 
     sd->discard(bytes);
@@ -209,16 +185,11 @@ void mpgfile::decodegop(int start, int stop, std::list<avframe*> &framelist)
 
   if (pic < stop)
   {
-    int frameFinished=0;
-
-    AVPacket pkt;
-    av_init_packet( &pkt );
-    pkt.data = NULL;
-    pkt.size = 0;
-    avcodec_decode_video2( S->avcc, avf,
-                                        &frameFinished, &pkt );
-
-    if (frameFinished)
+    AVPacket* pkt = av_packet_alloc();
+    pkt->data = NULL;
+    pkt->size = 0;
+    avcodec_send_packet(S->avcc, pkt);
+    while (avcodec_receive_frame(S->avcc, avf) == 0)
     {
       if (last_cpn!=avf->coded_picture_number)
       {
@@ -227,6 +198,7 @@ void mpgfile::decodegop(int start, int stop, std::list<avframe*> &framelist)
           framelist.push_back(new avframe(avf,S->avcc));
       }
     }
+    av_packet_free(&pkt);
   }
 
   time_base_num = S->avcc->time_base.num;
@@ -765,13 +737,11 @@ void mpgfile::recodevideo(muxer &mux, int start, int stop, pts_t offset,int save
   pts_t startpts=idx[idx.indexnr(start)].getpts();
   while (outpicture<stop)
   {
-    AVPacket pkt;
+    AVPacket* pkt = av_packet_alloc();
     u_int8_t *buf=(u_int8_t*)m2v.writeptr();
-    int ret, got_output;
 
-    av_init_packet(&pkt);
-    pkt.data = buf;
-    pkt.size = m2v.getsize();
+    pkt->data = buf;
+    pkt->size = m2v.getsize();
 
     if (!framelist.empty())
     {
@@ -781,35 +751,41 @@ void mpgfile::recodevideo(muxer &mux, int start, int stop, pts_t offset,int save
       f->coded_picture_number=f->display_picture_number=p;
       f->key_frame=(p==0)?1:0;
       f->pict_type=(p==0)?AV_PICTURE_TYPE_I : AV_PICTURE_TYPE_P;
-      ret = avcodec_encode_video2(avcc, &pkt, f, &got_output);
+      avcodec_send_frame(avcc, f);
 
       delete framelist.front();
       framelist.pop_front();
       ++p;
 
-      if (ret < 0 || !got_output)
+      if (avcodec_receive_packet(avcc, pkt) != 0) {
+        av_packet_free(&pkt);
         continue;
+      }
     }
     else
     {
       fprintf(stderr,"trying to call avcodec_encode_video with frame=0\n");
-      ret = avcodec_encode_video2(avcc, &pkt, NULL, &got_output);
+      avcodec_send_frame(avcc, NULL);
       fprintf(stderr,"...back I am.\n");
 
-      if (ret < 0 || !got_output)
+      if (avcodec_receive_packet(avcc, pkt) != 0) {
+        av_packet_free(&pkt);
         break;
+      }
     }
 
     pts_t vidpts=idx[idx.indexnr(outpicture)].getpts()-offset;
     pts_t viddts=mux.getdts(VIDEOSTREAM);
     mux.setdts(VIDEOSTREAM,vidpts);
-    fixtimecode(pkt.data, pkt.size, vidpts);
-    mux.putpacket(VIDEOSTREAM,pkt.data,pkt.size,vidpts,viddts,
-                  (pkt.flags & AV_PKT_FLAG_KEY)?MUXER_FLAG_KEY:0 );
+    fixtimecode(pkt->data, pkt->size, vidpts);
+    mux.putpacket(VIDEOSTREAM, pkt->data, pkt->size, vidpts, viddts,
+                  (pkt->flags & AV_PKT_FLAG_KEY)?MUXER_FLAG_KEY:0 );
     ++outpicture;
 
     if (log && savepics>0)
       log->setprogress(++savedpics*1000/savepics);
+
+    av_packet_free(&pkt);
   }
 
   for(std::list<avframe*>::iterator fit=framelist.begin();fit!=framelist.end();++fit)
